@@ -1,13 +1,34 @@
 package SOAP::WSDL::XSD::Typelib::Builtin::boolean;
 use strict;
 use warnings;
-use Class::Std::Storable;
-use base qw(SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType);
+
+# Speed up. Class::Std::new is slow - and we don't need it's functionality...
+BEGIN {
+    use Class::Std::Storable;
+    use base qw(SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType);
+}
 
 my %pattern_of          :ATTR(:name<pattern> :default<()>);
 my %whiteSpace_of       :ATTR(:name<whiteSpace> :default<()>);
+my %value_of            :ATTR(:get<value> :init_attr<value> :default<()>);
+
+{
+    no warnings qw(redefine);
+    no strict qw(refs);
+
+    # Yes, I know it's ugly - but this is the fastest constructor to write 
+    # for Class::Std-Style inside out objects..
+    *{ __PACKAGE__ . '::new' } = sub {   
+        my $self = bless \do { my $foo } , shift;
+        if (@_) {
+            $value_of{ ident $self } = $_[0]->{ value }
+                if exists $_[0]->{ value }
+        }
+        return $self;
+    };
+
+}
 
-my %value_of :ATTR(:get<value> :init_attr<value> :default<()>);
 
 sub serialize {
     my ($self, $opt) = @_;
@@ -33,6 +54,8 @@ sub set_value {
         : 0;
 }
 
+
+
 Class::Std::initialize();   # make :BOOLIFY overloading serializable
 
 1;
